package com.bootdo.datas.service;

import cn.com.scca.api.DefaultSccaClient;
import cn.com.scca.api.SccaClient;
import cn.com.scca.api.data.request.message.SendSmsByTemplateRequest;
import cn.com.scca.api.data.response.message.SendSmsByTemplateResponse;
import cn.com.scca.api.error.ApiException;
import cn.com.scca.api.result.ResponseResult;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

/**
 * @author zhouhj
 */
@Service
public class MessageService {

    @Value("${message_gateway.prefix:#{null}}")
    private String gateWayPrefix;

    @Value("${message_gateway.appId:#{null}}")
    private String gatewayAppId;

    @Value("${message_gateway.appKey:#{null}}")
    private String gatewayAppKey;

    @Value("${message_gateway.catalog_record.templateId:#{null}}")
    private String catalogTemplateId;

    @Value("${message_gateway.risk_assessment.templateId:#{null}}")
    private String riskTemplateId;

    /**
     * 重要和核心数据目录审核驳回通知
     * @param phoneNumberList 手机集合
     * @param templateParams  风险名称
     * @return
     */
    public Integer importance(String phoneNumberList, String templateParams) {
        SccaClient sccaClient = new DefaultSccaClient(
                this.gateWayPrefix,
                this.gatewayAppId,
                gatewayAppKey);
        SendSmsByTemplateRequest request = new SendSmsByTemplateRequest();
        request.setTempleteId(this.catalogTemplateId);
        request.setTempleteParams(templateParams);
        request.setPhoneNumberList(phoneNumberList);
        ResponseResult<SendSmsByTemplateResponse> execute = null;
        try {
            execute = sccaClient.execute(request);
        } catch (ApiException e) {
            e.printStackTrace();
            throw new RuntimeException(e.getMessage());
        }
        System.out.println("====短信发送反馈状态码:" + execute.getResult_code() + "====反馈信息：" + execute.getResult_msg());
        return execute.getResult_code();
    }

    /**
     * 安全风险评估审核驳回通知
     * @param phoneNumberList 手机集合
     * @param templateParams 风险名称
     * @return
     */
    public Integer securityRisk(String phoneNumberList, String templateParams) {
        SccaClient sccaClient = new DefaultSccaClient(
                gateWayPrefix,
                this.gatewayAppId,
                this.gatewayAppKey);
        SendSmsByTemplateRequest request = new SendSmsByTemplateRequest();
        request.setTempleteId(this.riskTemplateId);
        request.setTempleteParams(templateParams);
        request.setPhoneNumberList(phoneNumberList);
        ResponseResult<SendSmsByTemplateResponse> execute = null;
        try {
            execute = sccaClient.execute(request);
        } catch (ApiException e) {
            throw new RuntimeException(e);
        }
        System.out.println("====短信发送反馈状态码:" + execute.getResult_code() + "====反馈信息：" + execute.getResult_msg());
        return execute.getResult_code();
    }
}
